| Title: | R SDK for `AWS Sagemaker` |
|---|---|
| Description: | A library for training and deploying machine learning models on Amazon SageMaker <https://aws.amazon.com/sagemaker/> using R through `paws SDK`. |
| Authors: | Dyfan Jones [aut, cre], Amazon.com, Inc. [cph] |
| Maintainer: | Dyfan Jones <[email protected]> |
| License: | Apache License (>= 2.0) |
| Version: | 1.0.9000 |
| Built: | 2026-05-20 06:58:06 UTC |
| Source: | https://github.com/DyfanJones/sagemaker-r-sdk |
A library for training and deploying machine learning models on Amazon SageMaker <https://aws.amazon.com/sagemaker/> using R through 'paws SDK'.
Maintainer: Dyfan Jones [email protected]
Other contributors:
Amazon.com, Inc. [copyright holder]